-----------------------------------------------------------------------------------------
--
-- main.lua
--
-----------------------------------------------------------------------------------------

-- ステータスバーを消す
display.setStatusBar(display.HiddenStatusBar)


-- 表示位置
local centerX    = display.contentCenterX
local dateY      = display.contentHeight * 0.2
local dayOfWeekY = display.contentHeight * 0.3
local timeY      = display.contentHeight * 0.5

-- 時分秒のY座標の表示位置
local time1x = display.contentWidth * 0.15
local time2x = display.contentWidth * 0.3
local time3x = display.contentWidth * 0.54
local time4x = display.contentWidth * 0.69
local time5x = display.contentWidth * 0.82
local time6x = display.contentWidth * 0.9

-- 描画オブジェクト（グループ）の保存用変数を宣言
local dateText = nil          -- 日付
local dayOfWeekText = nil     -- 曜日
local hour1 = nil             -- 時（10の位）
local hour2 = nil             -- 時（1の位）
local minute1 = nil           -- 分（10の位）
local minute2 = nil           -- 分（1の位）
local sec1 = nil              -- 秒（10の位）
local sec2 = nil              -- 秒（1の位）
local colon1 = nil            -- コロンの上
local colon2 = nil            -- コロンの下


-----------------------------------------------------------------------------------------
-- 関数名 : DelImage
-- 内  容 : 指定した描画オブジェクトを削除
-- 戻り値 : なし
-----------------------------------------------------------------------------------------
local function DelImage(target)
    if (target ~= nil) then
        display.remove(target)
        target = nil
    end
end

-----------------------------------------------------------------------------------------
-- 関数名 : Make7Seg
-- 内  容 : 7セグメントディスプレイ風の絵を作成
-- 戻り値 : 1桁分の7セグ
-----------------------------------------------------------------------------------------
local function Make7Seg(num)
    local group7Seg = display.newGroup()
    
    local halfWidth = 4
    local topHeight = 6
    local midHeight = 16
    local vertices = {0, 0, 
                      halfWidth, topHeight, 
                      halfWidth, topHeight + midHeight, 
                      0, topHeight * 2 + midHeight, 
                      -halfWidth, topHeight + midHeight, 
                      -halfWidth, topHeight}
    -- 1度すべて作成
    local data1 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data2 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data3 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data4 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data5 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data6 = display.newPolygon(group7Seg, 100, 10, vertices)
    local data7 = display.newPolygon(group7Seg, 100, 10, vertices)
    
    -- 位置合わせ
    data1.x = 0
    data1.y = 0
    data2.x = data1.x
    data2.y = data1.y + data1.height
    data3.x = data1.x + data1.height
    data3.y = 0
    data4.x = data1.x + data1.height
    data4.y = data1.y + data1.height
    data5.rotation = 90
    data5.x = data1.x + data5.height * 0.5
    data5.y = data1.y - data5.height * 0.5
    data6.rotation = 90
    data6.x = data1.x + data6.height * 0.5
    data6.y = data1.y + data6.height * 0.5
    data7.rotation = 90
    data7.x = data1.x + data6.height * 0.5
    data7.y = data1.y + data6.height * 1.5
    
    -- 不要な部分を削除
    if (num == 1) then
        data1.isVisible = false
        data2.isVisible = false
        data5.isVisible = false
        data6.isVisible = false
        data7.isVisible = false
    elseif (num == 2) then
        data1.isVisible = false
        data4.isVisible = false
    elseif (num == 3) then
        data1.isVisible = false
        data2.isVisible = false
    elseif (num == 4) then
        data2.isVisible = false
        data5.isVisible = false
        data7.isVisible = false
    elseif (num == 5) then
        data2.isVisible = false
        data3.isVisible = false
    elseif (num == 6) then
        data3.isVisible = false
    elseif (num == 7) then
        data1.isVisible = false
        data2.isVisible = false
        data6.isVisible = false
        data7.isVisible = false
    elseif (num == 8) then
        -- Empty
    elseif (num == 9) then
        data2.isVisible = false
    else
        data6.isVisible = false
    end

    group7Seg.anchorChildren = true
    return group7Seg
end

-----------------------------------------------------------------------------------------
-- 関数名 : GetDayOfWeekText
-- 内  容 : 曜日の文字列を取得する
-- 戻り値 : 日本語の曜日の文字列
-----------------------------------------------------------------------------------------
local function GetDayOfWeekText(num)
    if (num == 1) then
        return "日曜日"
    elseif (num == 2) then
        return "月曜日"
    elseif (num == 3) then
        return "火曜日"
    elseif (num == 4) then
        return "水曜日"
    elseif (num == 5) then
        return "木曜日"
    elseif (num == 6) then
        return "金曜日"
    else
        return "土曜日"
    end
end

-----------------------------------------------------------------------------------------
-- 関数名 : UpdateDateTime
-- 内  容 : 表示日時を更新する
-- 戻り値 : なし
-----------------------------------------------------------------------------------------
local function UpdateDateTime()
    -- 現在日時を取得
    local now = os.date("*t")
    -- 日付の表示
    DelImage(dateText)
    local dateString = string.format("%d年 %2d月 %2d日", now.year, now.month, now.day)
    dateText = display.newText(dateString, centerX, dateY, native.systemFont, 30)
    -- 曜日の表示
    DelImage(dayOfWeekText)
    dayOfWeekText = display.newText(GetDayOfWeekText(now.wday), centerX, dayOfWeekY, native.systemFont, 30)

    -- 時間の表示
    -- 時
    DelImage(hour1)
    DelImage(hour2)
    hour1 = Make7Seg(math.floor(now.hour / 10))
    hour1.x = time1x
    hour1.y = timeY
    hour2 = Make7Seg(now.hour % 10)
    hour2.x = time2x
    hour2.y = timeY

    -- 時間のコロン作成
    DelImage(colon1)
    DelImage(colon2)
    colon1 = display.newCircle(display.contentWidth * 0.42, timeY - 14, 4)
    colon2 = display.newCircle(display.contentWidth * 0.42, timeY + 14, 4)

    -- 分
    DelImage(minute1)
    DelImage(minute2)
    minute1 = Make7Seg(math.floor(now.min / 10))
    minute1.x = time3x
    minute1.y = timeY
    minute2 = Make7Seg(now.min % 10)
    minute2.x = time4x
    minute2.y = timeY

    -- 秒
    DelImage(sec1)
    DelImage(sec2)
    sec1 = Make7Seg(math.floor(now.sec / 10))
    sec1.xScale = 0.5
    sec1.yScale = 0.5
    sec1.x = time5x
    sec1.y = timeY + sec1.height * 0.25
    sec2 = Make7Seg(now.sec % 10)
    sec2.xScale = 0.5
    sec2.yScale = 0.5
    sec2.x = time6x
    sec2.y = timeY + sec2.height * 0.25
end

-- 表示日時を一定間隔で更新用のタイマ
timer.performWithDelay(100, UpdateDateTime, -1)

